@@ -1,5 +1,5 @@
 #
-# Copyright 2012-2020 Ghent University
+# Copyright 2012-2021 Ghent University
 #
 # This file is part of vsc-utils,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -42,8 +42,8 @@ from vsc.utils.availability import proceed_on_ha_service
 from vsc.utils.generaloption import SimpleOption
 from vsc.utils.lock import lock_or_bork, release_or_bork, LOCKFILE_DIR, LOCKFILE_FILENAME_TEMPLATE
 from vsc.utils.nagios import (
-    SimpleNagios, NAGIOS_CACHE_DIR, NAGIOS_CACHE_FILENAME_TEMPLATE, NAGIOS_EXIT_OK,
-    exit_from_errorcode
+    SimpleNagios, NAGIOS_CACHE_DIR, NAGIOS_CACHE_FILENAME_TEMPLATE, exit_from_errorcode,
+    NAGIOS_EXIT_OK, NAGIOS_EXIT_WARNING, NAGIOS_EXIT_CRITICAL, NAGIOS_EXIT_UNKNOWN,
 )
 from vsc.utils.timestamp import (
     convert_timestamp, write_timestamp, retrieve_timestamp_with_default
@@ -160,7 +160,7 @@ class ExtendedSimpleOption(SimpleOption):
 
         # check for HA host
         if self.options.ha and not proceed_on_ha_service(self.options.ha):
-            self.log.warning("Not running on the target host %s in the HA setup. Stopping." % (self.options.ha,))
+            self.log.warning("Not running on the target host %s in the HA setup. Stopping.", self.options.ha)
             self.nagios_reporter.ok("Not running on the HA master.")
             sys.exit(NAGIOS_EXIT_OK)
 
@@ -169,7 +169,7 @@ class ExtendedSimpleOption(SimpleOption):
                                                    threshold=self.options.nagios_check_interval_threshold * 2)
             lock_or_bork(self.lockfile, self.nagios_reporter)
 
-        self.log.info("%s has started" % (_script_name(sys.argv[0])))
+        self.log.info("%s has started", _script_name(sys.argv[0]))
 
     def _epilogue(self):
         if not self.options.disable_locking and not self.options.dry_run:
@@ -184,7 +184,7 @@ class ExtendedSimpleOption(SimpleOption):
 
         nagios_thresholds['message'] = nagios_message
         self.nagios_reporter._eval_and_exit(**nagios_thresholds)
-        self.log.info("%s has finished" % (_script_name(sys.argv[0])))  # may not be reached
+        self.log.info("%s has finished", _script_name(sys.argv[0]))  # may not be reached
 
     def ok(self, nagios_message):
         """Run at the end of a script and force an OK exit."""
@@ -224,7 +224,6 @@ class ExtendedSimpleOption(SimpleOption):
         self.log.exception("unhandled exception detected: %s - %s", tp, value)
         self.log.debug("traceback %s", traceback)
         message = "Script failure: %s - %s" % (tp, value)
-        sys.exc_clear()
         self.critical(message)
 
 
@@ -256,6 +255,7 @@ class CLI(object):
         self.start_timestamp = None
         self.current_time = None
 
+
     def make_options(self, defaults=None):
         """
         Take the default sync options, set the default timestamp file and merge
@@ -281,17 +281,37 @@ class CLI(object):
 
         return ExtendedSimpleOption(options)
 
+    def ok(self, msg):
+        """
+        Convenience method that calls ExtendedSimpleOptions ok and exists with nagios OK exitcode
+        """
+        logging.info(msg)
+        self.fulloptions.ok(msg)
+        sys.exit(NAGIOS_EXIT_OK[0])
+
     def warning(self, msg):
         """
         Convenience method that calls ExtendedSimpleOptions warning and exists with nagios warning exitcode
         """
-        exit_from_errorcode(1, msg)
+        logging.warning(msg)
+        self.fulloptions.warning(msg)
+        sys.exit(NAGIOS_EXIT_WARNING[0])
 
     def critical(self, msg):
         """
         Convenience method that calls ExtendedSimpleOptions critical and exists with nagios critical exitcode
         """
-        exit_from_errorcode(2, msg)
+        logging.error(msg)
+        self.fulloptions.critical(msg)
+        sys.exit(NAGIOS_EXIT_CRITICAL[0])
+
+    def unknown(self, msg):
+        """
+        Convenience method that calls ExtendedSimpleOptions unknown and exists with nagios unknown exitcode
+        """
+        logging.error(msg)
+        self.fulloptions.unknown(msg)
+        sys.exit(NAGIOS_EXIT_UNKNOWN[0])
 
     def critical_exception(self, msg, exception):
         """
@@ -313,6 +333,7 @@ class CLI(object):
         """
         logging.error("`do` method not implemented")
         raise Exception("Not implemented")
+        return "Not implemented"
 
     def make_time(self):
         """
@@ -345,8 +366,8 @@ class CLI(object):
             current_time = self.current_time
 
         if errors:
-            logging.warning("Could not process all %s", errors)
-            self.warning("Not all processed")
+            logging.warning("Encountered errors: %s", errors)
+            self.warning("Failed to complete without errors.")
         elif not self.options.dry_run:
             # don't update the timestamp on dryrun
             timestamp = -1  # handle failing convert_timestamp
@@ -369,7 +390,7 @@ class CLI(object):
         """
         errors = []
 
-        msg = "Sync"
+        msg = self.name
         if self.options.dry_run:
             msg += " (dry-run)"
         logging.info("%s started.", msg)
@@ -386,3 +407,34 @@ class CLI(object):
         self.post(errors)
 
         self.fulloptions.epilogue("%s complete" % msg, self.thresholds)
+
+
+
+class NrpeCLI(CLI):
+
+    def __init__(self, name=None, default_options=None):
+        super(NrpeCLI, self).__init__(name=name, default_options=default_options)
+
+    def ok(self, msg):
+        """
+        Convenience method that exists with nagios OK exitcode
+        """
+        exit_from_errorcode(0, msg)
+
+    def warning(self, msg):
+        """
+        Convenience method exists with nagios warning exitcode
+        """
+        exit_from_errorcode(1, msg)
+
+    def critical(self, msg):
+        """
+        Convenience method that exists with nagios critical exitcode
+        """
+        exit_from_errorcode(2, msg)
+
+    def unknown(self, msg):
+        """
+        Convenience method that exists with nagios unknown exitcode
+        """
+        exit_from_errorcode(3, msg)
